@@ -2,6 +2,6 @@
 Explanations Metrics module
 """
 
-from .fidelity import MuFidelity, Deletion, Insertion
+from .fidelity import MuFidelity, Deletion, Insertion, DeletionTS, InsertionTS
 from .stability import AverageStability
 from .representativity import MeGe
